<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet SYSTEM "SCA Coverage Report.dtd">
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:gfn="http://www.greenhatsoftware.com/Functions.xsl"
	exclude-result-prefixes="gfn">

	<xsl:include href="Utils/Functions.xsl" />

	<xsl:output method="html" encoding="UTF-8" indent="yes" />

	<!-- externalisations -->
	<xsl:variable name="scaCoverageReport.title">
		<xsl:text>&scaCoverageReport.title;</xsl:text>
	</xsl:variable>
	<xsl:variable name="scaCoverageReport.heading">
		<xsl:text>&scaCoverageReport.heading;</xsl:text>
	</xsl:variable>
	<xsl:variable name="scaCoverageReport.summary">
		<xsl:text>&scaCoverageReport.summary;</xsl:text>
	</xsl:variable>
	<xsl:variable name="scaCoverageReport.composite">
		<xsl:text>&scaCoverageReport.composite;</xsl:text>
	</xsl:variable>
	<xsl:variable name="scaCoverageReport.componentsRun">
		<xsl:text>&scaCoverageReport.componentsRun;</xsl:text>
	</xsl:variable>
	<xsl:variable name="scaCoverageReport.summaryComponentsMissed">
		<xsl:text>&scaCoverageReport.summaryComponentsMissed;</xsl:text>
	</xsl:variable>
	<xsl:variable name="scaCoverageReport.coverage">
		<xsl:text>&scaCoverageReport.coverage;</xsl:text>
	</xsl:variable>
	<xsl:variable name="scaCoverageReport.total">
		<xsl:text>&scaCoverageReport.total;</xsl:text>
	</xsl:variable>
	<xsl:variable name="scaCoverageReport.detail">
		<xsl:text>&scaCoverageReport.detail;</xsl:text>
	</xsl:variable>
	<xsl:variable name="scaCoverageReport.detailComponentsMissed">
		<xsl:text>&scaCoverageReport.detailComponentsMissed;</xsl:text>
	</xsl:variable>
	<xsl:variable name="scaCoverageReport.detailComponentsCovered">
		<xsl:text>&scaCoverageReport.detailComponentsCovered;</xsl:text>
	</xsl:variable>
	<xsl:variable name="scaCoverageReport.percentageString">
		<xsl:text>&scaCoverageReport.percentageString;</xsl:text>
	</xsl:variable>
	<xsl:variable name="scaCoverageReport.nameAndPercentCoverage">
		<xsl:text>&scaCoverageReport.nameAndPercentCoverage;</xsl:text>
	</xsl:variable>

	<xsl:template match="/">
		<xsl:variable name="y" select="//coverage[1]" />
		<html>
			<head>
				<title>
					<xsl:value-of select="$scaCoverageReport.title" />
				</title>
				<link rel="stylesheet" type="text/css" href="resourcestyle.css" />
				<link rel="stylesheet" type="text/css" href="vanilla.css" />
			</head>
			<body>
				<h1>
					<xsl:value-of select="$scaCoverageReport.heading" />
				</h1>
				<h2>
					<xsl:value-of select="$scaCoverageReport.summary" />
				</h2>
				<div>
					<table>
						<thead>
							<tr>
								<th class="left">
									<xsl:value-of select="$scaCoverageReport.composite" />
								</th>
								<th>
									<xsl:value-of select="$scaCoverageReport.componentsRun" />
								</th>
								<th>
									<xsl:value-of select="$scaCoverageReport.summaryComponentsMissed" />
								</th>
								<th>
									<xsl:value-of select="$scaCoverageReport.coverage" />
								</th>
							</tr>
						</thead>
						<tbody>
							<xsl:for-each select="$y/processes/process">
								<tr>
									<td class="left">
										<xsl:value-of select="@name" />
									</td>
									<td>
										<xsl:value-of select="count(activities/activity[@frq > 0])" />
									</td>
									<td>
										<xsl:value-of select="count(activities/activity[not(@frq > 0)])" />
									</td>
									<td>
										<xsl:value-of
											select="gfn:getRoundPercentage(count(activities/activity[@frq > 0]),count(activities/activity))" />
									</td>
								</tr>
							</xsl:for-each>
						</tbody>
						<tfoot>
							<tr>
								<th class="left">
									<xsl:value-of select="$scaCoverageReport.total" />
								</th>
								<th>
									<xsl:value-of
										select="count($y/processes/process/activities/activity[@frq > 0])" />
								</th>
								<th>
									<xsl:value-of
										select="count($y/processes/process/activities/activity[not(@frq > 0)])" />
								</th>
								<th>
									<xsl:value-of
										select="gfn:formatString($scaCoverageReport.percentageString,round(100 * avg( for $x in $y/processes/process return if ($x/activities/activity) then count($x/activities/activity[@frq > 0]) div count($x/activities/activity) else 0)))" />
								</th>
							</tr>
						</tfoot>
					</table>
				</div>
				<xsl:if test="$y/processes/process[activities/activity[@frq > 0]]">
					<h2>
						<xsl:value-of select="$scaCoverageReport.detail" />
					</h2>
					<xsl:for-each select="$y/processes/process[activities/activity[@frq > 0]]">
						<h3>
							<xsl:value-of
								select="gfn:formatString($scaCoverageReport.nameAndPercentCoverage,@name, round(100 * count(activities/activity[@frq > 0]) div count(activities/activity)))" />
						</h3>
						<div>
							<xsl:if test="activities/activity[not(@frq > 0)]">
								<h4>
									<xsl:value-of select="$scaCoverageReport.detailComponentsMissed" />
								</h4>
								<ul>
									<xsl:for-each select="activities/activity[not(@frq > 0)]">
										<li>
											<xsl:value-of select="@name" />
										</li>
									</xsl:for-each>
								</ul>
							</xsl:if>
							<xsl:if test="activities/activity[@frq > 0]">
								<h4>
									<xsl:value-of select="$scaCoverageReport.detailComponentsCovered" />
								</h4>
								<ul>
									<xsl:for-each select="activities/activity[@frq > 0]">
										<li>
											<xsl:value-of select="@name" />
										</li>
									</xsl:for-each>
								</ul>
							</xsl:if>
						</div>
					</xsl:for-each>
				</xsl:if>
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>