<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet SYSTEM "Test Suite Detailed Report.dtd">
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:gfn="http://www.greenhatsoftware.com/Functions.xsl"
	exclude-result-prefixes="gfn">

	<xsl:import href="Utils/Misc.xsl" />
	<xsl:import href="Detailed%20Report.xsl" />

	<xsl:output method="html" encoding="UTF-8" indent="yes" />

	<!-- externalisations -->
	<xsl:variable name="testSuiteDetailedReport.resourceNameAndReportTitle">
		<xsl:text>&testSuiteDetailedReport.resourceNameAndReportTitle;</xsl:text>
	</xsl:variable>
	<xsl:variable name="testSuiteDetailedReport.suite">
		<xsl:text>&testSuiteDetailedReport.suite;</xsl:text>
	</xsl:variable>
	<xsl:variable name="testSuiteDetailedReport.scenario">
		<xsl:text>&testSuiteDetailedReport.scenario;</xsl:text>
	</xsl:variable>
	<xsl:variable name="testSuiteDetailedReport.environments">
		<xsl:text>&testSuiteDetailedReport.environments;</xsl:text>
	</xsl:variable>
	<xsl:variable name="testSuiteDetailedReport.environment">
		<xsl:text>&testSuiteDetailedReport.environment;</xsl:text>
	</xsl:variable>
	<xsl:variable name="testSuiteDetailedReport.overallStatus">
		<xsl:text>&testSuiteDetailedReport.overallStatus;</xsl:text>
	</xsl:variable>
	<xsl:variable name="testSuiteDetailedReport.runTime">
		<xsl:text>&testSuiteDetailedReport.runTime;</xsl:text>
	</xsl:variable>
	<xsl:variable name="testSuiteDetailedReport.running">
		<xsl:text>&testSuiteDetailedReport.running;</xsl:text>
	</xsl:variable>
	<xsl:variable name="testSuiteDetailedReport.startTime">
		<xsl:text>&testSuiteDetailedReport.startTime;</xsl:text>
	</xsl:variable>
	<xsl:variable name="testSuiteDetailedReport.testsPassed">
		<xsl:text>&testSuiteDetailedReport.testsPassed;</xsl:text>
	</xsl:variable>
	<xsl:variable name="testSuiteDetailedReport.endTime">
		<xsl:text>&testSuiteDetailedReport.endTime;</xsl:text>
	</xsl:variable>
	<xsl:variable name="testSuiteDetailedReport.testsFailed">
		<xsl:text>&testSuiteDetailedReport.testsFailed;</xsl:text>
	</xsl:variable>
	<xsl:variable name="testSuiteDetailedReport.summary">
		<xsl:text>&testSuiteDetailedReport.summary;</xsl:text>
	</xsl:variable>
	<xsl:variable name="testSuiteDetailedReport.resource">
		<xsl:text>&testSuiteDetailedReport.resource;</xsl:text>
	</xsl:variable>
	<xsl:variable name="testSuiteDetailedReport.result">
		<xsl:text>&testSuiteDetailedReport.result;</xsl:text>
	</xsl:variable>
	<xsl:variable name="testSuiteDetailedReport.errors">
		<xsl:text>&testSuiteDetailedReport.errors;</xsl:text>
	</xsl:variable>
	<xsl:variable name="testSuiteDetailedReport.warnings">
		<xsl:text>&testSuiteDetailedReport.warnings;</xsl:text>
	</xsl:variable>
	<xsl:variable name="testSuiteDetailedReport.statusRunning">
		<xsl:text>&testSuiteDetailedReport.statusRunning;</xsl:text>
	</xsl:variable>
	<xsl:variable name="testSuiteDetailedReport.passed">
		<xsl:text>&testSuiteDetailedReport.passed;</xsl:text>
	</xsl:variable>
	<xsl:variable name="testSuiteDetailedReport.cancelled">
		<xsl:text>&testSuiteDetailedReport.cancelled;</xsl:text>
	</xsl:variable>
	<xsl:variable name="testSuiteDetailedReport.failed">
		<xsl:text>&testSuiteDetailedReport.failed;</xsl:text>
	</xsl:variable>

	<xsl:param name="contextName" />
	<xsl:param name="title"
		select="gfn:formatString($testSuiteDetailedReport.resourceNameAndReportTitle, tokenize($contextName,'/')[last()])" />

	<xsl:template match="/">
		<html>
			<head>
				<title>
					<xsl:value-of select="$title" />
				</title>
				<link rel="stylesheet" type="text/css" href="resourcestyle.css" />
				<link rel="stylesheet" type="text/css" href="iprocessstyles.css" />
			</head>
			<body>
				<a name="top" />
				<xsl:variable name="results"
					select="document(TestSuite/task/@logLocation)/Test/summary" />
				<xsl:call-template name="head">
					<xsl:with-param name="results" select="$results" />
				</xsl:call-template>
				<xsl:call-template name="summary">
					<xsl:with-param name="results" select="$results" />
				</xsl:call-template>
				<xsl:call-template name="table">
					<xsl:with-param name="results" select="$results" />
				</xsl:call-template>

				<xsl:for-each select="$results/..">
					<xsl:value-of select="'&lt;pd4ml:page.break&gt;'"
						disable-output-escaping="yes" />
					<a href="#top">&lt;&lt;top</a>
					<a>
						<xsl:attribute name="name" select="concat('Test',generate-id(.))" />
					</a>
					<xsl:apply-templates select="." />
				</xsl:for-each>
			</body>
		</html>
	</xsl:template>

	<xsl:template name="head">
		<xsl:param name="results" />
		<div style="margin: 0px 0px 10px 0px;">
			<img src="logo.jpg" alt="Logo" style="float: left;"
				border="0" />
			<h1>
				<xsl:value-of select="$title" />
			</h1>
			<table class="faux">
				<tr>
					<th>
						<xsl:value-of select="$testSuiteDetailedReport.suite" />
					</th>
					<td>
						<xsl:value-of select="$contextName" />
					</td>
				</tr>
				<tr>
					<th>
						<xsl:value-of select="$testSuiteDetailedReport.scenario" />
					</th>
					<td>
						<xsl:value-of select="TestSuite/@resource" />
					</td>
				</tr>
				<tr>
					<xsl:choose>
						<xsl:when
							test="count(distinct-values( $results/../environment/@name )) &gt; 1">
							<th>
								<xsl:value-of select="$testSuiteDetailedReport.environments" />
							</th>
						</xsl:when>
						<xsl:otherwise>
							<th>
								<xsl:value-of select="$testSuiteDetailedReport.environment" />
							</th>
						</xsl:otherwise>
					</xsl:choose>
					<td>
						<xsl:value-of
							select="string-join(distinct-values( $results/../environment/@name ), ', ')" />
					</td>
				</tr>
				<tr>
					<th>
						<xsl:value-of select="$testSuiteDetailedReport.overallStatus" />
					</th>
					<td>
						<xsl:variable name="status">
							<xsl:call-template name="status">
								<xsl:with-param name="results" select="$results" />
							</xsl:call-template>
						</xsl:variable>
						<xsl:variable name="statusString">
							<xsl:call-template name="statusString">
								<xsl:with-param name="results" select="$results" />
							</xsl:call-template>
						</xsl:variable>
						<xsl:attribute name="class">
							<xsl:value-of select="$status" />
						</xsl:attribute>
						<xsl:value-of select="$statusString" />
					</td>
				</tr>
				<tr>
					<xsl:call-template name="writeNameValuePair">
						<xsl:with-param name="name"
							select="$testSuiteDetailedReport.runTime" />
						<xsl:with-param name="value">
							<xsl:choose>
								<xsl:when test="TestSuite/@duration">
									<xsl:value-of select="TestSuite/@duration" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="$testSuiteDetailedReport.running" />
								</xsl:otherwise>
							</xsl:choose>
						</xsl:with-param>
					</xsl:call-template>
				</tr>
			</table>
		</div>
	</xsl:template>

	<xsl:template name="summary">
		<xsl:param name="results" />
		<xsl:variable name="startTime"
			select="translate(TestSuite/@startTime,'T',' ')" />
		<xsl:variable name="endTime">
			<xsl:choose>
				<xsl:when test="TestSuite/@endTime">
					<xsl:value-of select="translate(TestSuite/@endTime,'T',' ')" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$testSuiteDetailedReport.running" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="testsInSuite" select="count($results)" />
		<xsl:variable name="testsPassed"
			select="count($results[@overallStatus='Passed'])" />
		<xsl:variable name="testsFailed"
			select="count($results[@overallStatus='Failed'])" />
		<table class="faux">
			<tr>
				<xsl:call-template name="writeNameValuePair">
					<xsl:with-param name="name"
						select="$testSuiteDetailedReport.startTime" />
					<xsl:with-param name="value" select="$startTime" />
				</xsl:call-template>
				<td class="spacer" />
				<xsl:call-template name="writeNameValuePair">
					<xsl:with-param name="name"
						select="$testSuiteDetailedReport.testsPassed" />
					<xsl:with-param name="value"
						select="gfn:getPercentage($testsPassed,$testsInSuite)" />
				</xsl:call-template>
			</tr>
			<tr>
				<xsl:call-template name="writeNameValuePair">
					<xsl:with-param name="name"
						select="$testSuiteDetailedReport.endTime" />
					<xsl:with-param name="value" select="$endTime" />
				</xsl:call-template>
				<td class="spacer" />
				<xsl:call-template name="writeNameValuePair">
					<xsl:with-param name="name"
						select="$testSuiteDetailedReport.testsFailed" />
					<xsl:with-param name="value"
						select="gfn:getPercentage($testsFailed,$testsInSuite)" />
				</xsl:call-template>
			</tr>
		</table>
	</xsl:template>

	<xsl:template name="table">
		<xsl:param name="results" />
		<h2>
			<xsl:value-of select="$testSuiteDetailedReport.summary" />
		</h2>
		<table>
			<tr>
				<th>
					<xsl:value-of select="$testSuiteDetailedReport.resource" />
				</th>
				<th>
					<xsl:value-of select="$testSuiteDetailedReport.result" />
				</th>
				<th>
					<xsl:value-of select="$testSuiteDetailedReport.startTime" />
				</th>
				<th>
					<xsl:value-of select="$testSuiteDetailedReport.endTime" />
				</th>
				<th>
					<xsl:value-of select="$testSuiteDetailedReport.runTime" />
				</th>
				<th>
					<xsl:value-of select="$testSuiteDetailedReport.errors" />
				</th>
				<th>
					<xsl:value-of select="$testSuiteDetailedReport.warnings" />
				</th>
			</tr>
			<xsl:for-each select="TestSuite/task">
				<xsl:variable name="taskName">
					<xsl:value-of select="@name" />
				</xsl:variable>
				<xsl:variable name="logLocation">
					<xsl:value-of select="@logLocation" />
				</xsl:variable>
				<xsl:for-each select="document(@logLocation)/Test">
					<tr>
						<td>
							<a>
								<xsl:attribute name="href"
									select="concat('#Test',generate-id(.))" />
								<xsl:value-of select="$taskName" />
							</a>
						</td>
						<td>
							<xsl:variable name="statusKey" select="summary/@overallStatus" />
							<xsl:attribute name="class"
								select="lower-case(summary/@overallStatus)" />
							<xsl:call-template name="getOverallStatusString">
								<xsl:with-param name="statusKey" select="$statusKey" />
							</xsl:call-template>
						</td>
						<xsl:call-template name="reportTestStartTime">
							<xsl:with-param name="useTitle" select="0" />
						</xsl:call-template>
						<xsl:call-template name="reportTestEndTime">
							<xsl:with-param name="useTitle" select="0" />
						</xsl:call-template>
						<td class="figure">
							<xsl:call-template name="getTestExecutionTime" />
						</td>
						<td class="figure">
							<xsl:call-template name="getErrorMessages" />
						</td>
						<td class="figure">
							<xsl:call-template name="getWarningMessages" />
						</td>
					</tr>
				</xsl:for-each>
			</xsl:for-each>
		</table>
	</xsl:template>

	<xsl:template name="status">
		<xsl:param name="results" />
		<xsl:choose>
			<xsl:when test="not(TestSuite/@endTime)">
				<xsl:value-of select="'running'" />
			</xsl:when>
			<xsl:when
				test="count($results) = count($results[@overallStatus='Passed']) and count($results)!= 0">
				<xsl:value-of select="'passed'" />
			</xsl:when>
			<xsl:when test="$results[@overallStatus='Cancelled']">
				<xsl:value-of select="'cancelled'" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="'failed'" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- TODO Some duplication with getOverallStatusString in DetailedReport.xsl -->
	<xsl:template name="statusString">
		<xsl:param name="results" />
		<xsl:choose>
			<xsl:when test="not(TestSuite/@endTime)">
				<xsl:value-of select="$testSuiteDetailedReport.statusRunning" />
			</xsl:when>
			<xsl:when
				test="count($results) = count($results[@overallStatus='Passed']) and count($results)!= 0">
				<xsl:value-of select="$testSuiteDetailedReport.passed" />
			</xsl:when>
			<xsl:when test="$results[@overallStatus='Cancelled']">
				<xsl:value-of select="$testSuiteDetailedReport.cancelled" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$testSuiteDetailedReport.failed" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
