<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet SYSTEM "A3Message.dtd">
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

	<!-- externalisations -->
	<xsl:variable name="A3Message.msgName">
		<xsl:text>&A3Message.msgName;</xsl:text>
	</xsl:variable>
	<xsl:variable name="A3Message.payload">
		<xsl:text>&A3Message.payload;</xsl:text>
	</xsl:variable>

	<xsl:template name="reportAssociatedA3Message">
		<xsl:param name="index" />
		<xsl:choose>
			<xsl:when test="string-length(string($index))!=0">
				<xsl:apply-templates select="child::a3Message[$index]" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates select="child::a3Message" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="a3Message">

		<div class="a3Message">
			<table>
				<xsl:for-each select="child::*[1]">
					<xsl:call-template name="processMessage">
						<xsl:with-param name="msgName">
							<xsl:value-of select="$A3Message.msgName" />
						</xsl:with-param>
						<xsl:with-param name="rowClass">
							<xsl:value-of select="string('a3MessageTableHeader')" />
						</xsl:with-param>
					</xsl:call-template>
				</xsl:for-each>
				<xsl:call-template name="processA3MessageBody" />
			</table>
		</div>

	</xsl:template>

	<xsl:template name="processA3MessageBody">
		<xsl:choose>
			<xsl:when test="count(*)=1">
				<xsl:call-template name="createMessageField">
					<xsl:with-param name="name">
						<xsl:call-template name="getBodyName" />
					</xsl:with-param>
					<xsl:with-param name="rowClass">
						<xsl:value-of select="string('a3MessageTableHeader')" />
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:for-each select="child::*[2]">
					<xsl:call-template name="processMessage">
						<xsl:with-param name="msgName">
							<xsl:call-template name="getBodyName" />
						</xsl:with-param>
						<xsl:with-param name="rowClass">
							<xsl:value-of select="string('a3MessageTableHeader')" />
						</xsl:with-param>
					</xsl:call-template>
				</xsl:for-each>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="getBodyName">
		<xsl:choose>
			<xsl:when test="parent::a3Message[string-length(@name) &gt; 0]">
				<xsl:value-of select="../@name" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$A3Message.payload" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="messageField">
		<xsl:call-template name="createMessageField" />
	</xsl:template>

	<xsl:template name="createMessageField">
		<xsl:param name="name" select="@name" />
		<xsl:param name="rowClass" />
		<tr>
			<xsl:if test="string-length($rowClass)!=0">
				<xsl:attribute name="class">
                    <xsl:value-of select="$rowClass" />
                </xsl:attribute>
			</xsl:if>
			<th>
				<xsl:attribute name="style">
                    <xsl:value-of
					select="concat('padding: 0px 0px 0px ',10 * count(ancestor::message),'px;')" />
                </xsl:attribute>
				<xsl:value-of select="$name" />
			</th>
			<td>
				<xsl:call-template name="reportMessageFieldType" />
			</td>
			<td>
				<xsl:value-of select="@value" />
				<xsl:value-of select="@_GHB64_value" />
			</td>
		</tr>
	</xsl:template>

	<xsl:template name="processMessage">
		<xsl:param name="msgName" />
		<xsl:param name="rowClass" />
		<xsl:if test="name()='message' or string-length($msgName)!=0">
			<xsl:call-template name="reportMessage">
				<xsl:with-param name="msgName">
					<xsl:value-of select="$msgName" />
				</xsl:with-param>
				<xsl:with-param name="rowClass">
					<xsl:value-of select="$rowClass" />
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>




	<xsl:template name="reportMessage">
		<xsl:param name="msgName" />
		<xsl:param name="rowClass" />

		<xsl:choose>
			<xsl:when test="string-length($msgName)!=0">
				<xsl:call-template name="createMessageField">
					<xsl:with-param name="name" select="$msgName" />
					<xsl:with-param name="rowClass" select="$rowClass" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="createMessageField">
					<xsl:with-param name="name" select="@name" />
					<xsl:with-param name="rowClass" select="$rowClass" />
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>

		<xsl:if test="child::*">
			<xsl:for-each select="child::*">
				<xsl:choose>
					<xsl:when test="name()='messageField'">
						<xsl:apply-templates select="current()" />
					</xsl:when>
					<xsl:when test="name()='message'">
						<xsl:call-template name="processMessage" />
					</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
	</xsl:template>

	<xsl:template name="reportMessageFieldType">
		<xsl:choose>
			<xsl:when test="@*[name()=$META_TYPE]">
				<xsl:value-of select="@*[name()=$META_TYPE]" />
			</xsl:when>
			<xsl:when test="@*[name()=$TYPE]">
				<xsl:call-template name="convertMessageFieldType">
					<xsl:with-param name="type" select="@*[name()=$TYPE]" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$MESSAGE_TYPE_STRING" />
			</xsl:otherwise>
		</xsl:choose>
		<xsl:if test="@_GHB64_value">
			<I> (Base 64)</I>
		</xsl:if>
	</xsl:template>

	<xsl:template name="convertMessageFieldType">
		<xsl:param name="type" select="$STRING_TYPE_INT" />
		<xsl:choose>
			<xsl:when test="$type=$BYTE_TYPE_INT">
				<xsl:value-of select="$BYTE_TYPE_STRING" />
			</xsl:when>
			<xsl:when test="$type=$SHORT_TYPE_INT">
				<xsl:value-of select="$SHORT_TYPE_STRING" />
			</xsl:when>
			<xsl:when test="$type=$INT_TYPE_INT">
				<xsl:value-of select="$INT_TYPE_STRING" />
			</xsl:when>
			<xsl:when test="$type=$LONG_TYPE_INT">
				<xsl:value-of select="$LONG_TYPE_STRING" />
			</xsl:when>
			<xsl:when test="$type=$FLOAT_TYPE_INT">
				<xsl:value-of select="$FLOAT_TYPE_STRING" />
			</xsl:when>
			<xsl:when test="$type=$DOUBLE_TYPE_INT">
				<xsl:value-of select="$DOUBLE_TYPE_STRING" />
			</xsl:when>
			<xsl:when test="$type=$CHAR_TYPE_INT">
				<xsl:value-of select="$CHAR_TYPE_STRING" />
			</xsl:when>
			<xsl:when test="$type=$STRING_TYPE_INT">
				<xsl:value-of select="$STRING_TYPE_STRING" />
			</xsl:when>
			<xsl:when test="$type=$BOOLEAN_TYPE_INT">
				<xsl:value-of select="$BOOLEAN_TYPE_STRING" />
			</xsl:when>
			<xsl:when test="$type=$DATE_TYPE_INT">
				<xsl:value-of select="$DATE_TYPE_STRING" />
			</xsl:when>
			<xsl:when test="$type=$TIME_TYPE_INT">
				<xsl:value-of select="$TIME_TYPE_STRING" />
			</xsl:when>
			<xsl:when test="$type=$DATETIME_TYPE_INT">
				<xsl:value-of select="$DATETIME_TYPE_STRING" />
			</xsl:when>
			<xsl:when test="$type=$MESSAGE_TYPE_INT">
				<xsl:value-of select="$MESSAGE_TYPE_STRING" />
			</xsl:when>
			<xsl:when test="$type=$OBJECT_TYPE_INT">
				<xsl:value-of select="$OBJECT_TYPE_STRING" />
			</xsl:when>
			<xsl:when test="$type=$BYTEARRAY_TYPE_INT">
				<xsl:value-of select="$BYTEARRAY_TYPE_STRING" />
			</xsl:when>
			<xsl:when test="$type=$XML_TYPE_INT">
				<xsl:value-of select="$XML_TYPE_STRING" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$STRING_TYPE_STRING" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>